function [ A, n ] = Import( path , n_emergency )

% Import : load the data graph
%
% Parameters
%   path : a path of the data
%
% Return values
%   A : adjacency matrix of the graph
%   n : # of nodes

start_id = 1; % set start_id to 0 when index for node starts from 1 in your graph format

X = dlmread(path, '\t'); % change to X = dlmread(path); when delimiter is space 
X(:, 1) = X(:, 1) + start_id;
X(:, 2) = X(:, 2) + start_id;

n = max(max(X(:, 1), X(:, 2)));
A = sparse( X(:, 1), X(:, 2), 1, n, n);

% handle undirected graphs
if sum(sum(triu(A, 1))) == 0 || sum(sum(tril(A, -1))) == 0
    A = 1.0 * ((A + A') > 0);
end

% remove self loops
A = A - spdiags(diag(A), 0, n, n);
A = 1.0 * (A > 0);

end

